==> haskell-assoc-1.0.2-122-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-assoc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 assoc
version:              1.0.2
visibility:           public
id:                   assoc-1.0.2-3hqPvRJIvyvECBuNzExOFD
key:                  assoc-1.0.2-3hqPvRJIvyvECBuNzExOFD
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:             swap and assoc: Symmetric and Semigroupy Bifunctors
description:
    Provides generalisations of
    @swap :: (a,b) -> (b,a)@ and
    @assoc :: ((a,b),c) -> (a,(b,c))@
    to
    @Bifunctor@s supporting similar operations (e.g. @Either@, @These@).

category:             Data
abi:                  d403a1db2ce831abd7ed9b05fafd8473
exposed:              True
exposed-modules:      Data.Bifunctor.Assoc Data.Bifunctor.Swap
import-dirs:          /usr/lib/ghc-9.0.2/site-local/assoc-1.0.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/assoc-1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/assoc-1.0.2
hs-libraries:         HSassoc-1.0.2-3hqPvRJIvyvECBuNzExOFD
depends:
    base-4.15.1.0 bifunctors-5.5.11-CSHbd3Hp6gD84BJIoQGeID
    tagged-0.8.6.1-79gYUUazit6EfoPS33FHdR

haddock-interfaces:   /usr/share/doc/haskell-assoc/html/assoc.haddock
haddock-html:         /usr/share/doc/haskell-assoc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-assoc-1.0.2-124-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-assoc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 assoc
version:              1.0.2
visibility:           public
id:                   assoc-1.0.2-75YfnV4Srn46hJBRvDRWcc
key:                  assoc-1.0.2-75YfnV4Srn46hJBRvDRWcc
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:             swap and assoc: Symmetric and Semigroupy Bifunctors
description:
    Provides generalisations of
    @swap :: (a,b) -> (b,a)@ and
    @assoc :: ((a,b),c) -> (a,(b,c))@
    to
    @Bifunctor@s supporting similar operations (e.g. @Either@, @These@).

category:             Data
abi:                  63e0d5d469e355fa63841cd68925107b
exposed:              True
exposed-modules:      Data.Bifunctor.Assoc Data.Bifunctor.Swap
import-dirs:          /usr/lib/ghc-9.0.2/site-local/assoc-1.0.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/assoc-1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/assoc-1.0.2
hs-libraries:         HSassoc-1.0.2-75YfnV4Srn46hJBRvDRWcc
depends:
    base-4.15.1.0 bifunctors-5.5.11-90SBkbKYaGFDaUcBnhQoJM
    tagged-0.8.6.1-79gYUUazit6EfoPS33FHdR

haddock-interfaces:   /usr/share/doc/haskell-assoc/html/assoc.haddock
haddock-html:         /usr/share/doc/haskell-assoc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
